@@ -1,39 +1,39 @@
-
 #ifndef _SPI_H
 #define _SPI_H
 
-/* Implementation private definitions */
-#include "spi-impl.h"
+#include <glib/gmacros.h>
 
+#include <cspi/spi-impl.h>
 /*
- * Definitions for ACCESSIBLE_STATE , ACCESSIBLE_ROLE, AccessibleEvent,
- *      and event listeners.
+ * Definitions for AccessibleRole, AccessibleState,
+ * AccessibleEvent, and event listeners.
  */
+#include <cspi/spi-roletypes.h>
+#include <cspi/spi-statetypes.h>
+#include <cspi/spi-listener.h>
 
-#include "spi-roletypes.h"
-#include "spi-statetypes.h"
-#include "spi-listener.h"
+/*
+ * Auxiliary typedefs and mask definitions
+ */
+#include <libspi/keymasks.h>
+
+G_BEGIN_DECLS
 
 /*
- *
  * Enumerated type for text boundary types
- *
  */
-
 typedef enum
 {
-  TEXT_BOUNDARY_CHAR,
-  TEXT_BOUNDARY_CURSOR_POS,
-  TEXT_BOUNDARY_WORD_START,
-  TEXT_BOUNDARY_WORD_END,
-  TEXT_BOUNDARY_SENTENCE_START,
-  TEXT_BOUNDARY_SENTENCE_END,
-  TEXT_BOUNDARY_LINE_START,
-  TEXT_BOUNDARY_LINE_END,
-  TEXT_BOUNDARY_ATTRIBUTE_RANGE
-} TEXT_BOUNDARY_TYPE;
-
-
+  SPI_TEXT_BOUNDARY_CHAR,
+  SPI_TEXT_BOUNDARY_CURSOR_POS,
+  SPI_TEXT_BOUNDARY_WORD_START,
+  SPI_TEXT_BOUNDARY_WORD_END,
+  SPI_TEXT_BOUNDARY_SENTENCE_START,
+  SPI_TEXT_BOUNDARY_SENTENCE_END,
+  SPI_TEXT_BOUNDARY_LINE_START,
+  SPI_TEXT_BOUNDARY_LINE_END,
+  SPI_TEXT_BOUNDARY_ATTRIBUTE_RANGE
+} AccessibleTextBoundaryType;
 
 /*
  *
@@ -43,32 +43,75 @@ typedef enum
 
 typedef enum
 {
-  RELATION_LABEL_FOR,
-  RELATION_LABELED_BY,
-  RELATION_CONTROLLER_FOR,
-  RELATION_CONTROLLED_BY,
-  RELATION_MEMBER_OF
-} RELATION_TYPE;
+  SPI_RELATION_LABEL_FOR,
+  SPI_RELATION_LABELED_BY,
+  SPI_RELATION_CONTROLLER_FOR,
+  SPI_RELATION_CONTROLLED_BY,
+  SPI_RELATION_MEMBER_OF
+} AccessibleRelationType;
 
 
 /* don't change the order of these ! */
-typedef enum _AccessibleCoordType {
-  COORD_TYPE_SCREEN,
-  COORD_TYPE_WINDOW
+typedef enum {
+  SPI_COORD_TYPE_SCREEN,
+  SPI_COORD_TYPE_WINDOW
 } AccessibleCoordType;
 
-typedef enum _KeyEventType {
-  KEY_PRESSED,
-  KEY_RELEASED
-} KeyEventType;
+/* XXX: must be single bits since they are used as masks in keylistener API */
+typedef enum {
+  SPI_KEY_PRESSED = 1,
+  SPI_KEY_RELEASED = 2
+} AccessibleKeyEventType;
 
-typedef struct _KeyStroke
+typedef enum {
+  SPI_KEY_PRESS,
+  SPI_KEY_RELEASE, 
+  SPI_KEY_PRESSRELEASE,
+  SPI_KEY_SYM
+} AccessibleKeySynthType;
+
+typedef enum {
+  SPI_KEYLISTENER_NOSYNC = 0,
+  SPI_KEYLISTENER_SYNCHRONOUS = 1,
+  SPI_KEYLISTENER_CANCONSUME = 2,
+  SPI_KEYLISTENER_ALL_WINDOWS = 4
+} AccessibleKeyListenerSyncType;
+
+typedef unsigned long AccessibleKeyEventMask;
+
+typedef struct _AccessibleKeyStroke
 {
 	long keyID;
-	KeyEventType type;
+	short keycode;
+	long timestamp;
+	AccessibleKeyEventType type;
 	unsigned short modifiers;
-} KeyStroke;
+} AccessibleKeyStroke;
 
+/**
+ * AccessibleKeySet:
+ * @keysyms:
+ * @keycodes:
+ * @len:
+ *
+ * Structure containing identifying information about a set of keycode or
+ *        keysyms.
+ **/
+typedef struct _AccessibleKeySet
+{
+	unsigned long *keysyms;
+	unsigned short *keycodes;
+	short len;
+} AccessibleKeySet;
+
+/**
+ * SPI_KEYSET_ALL_KEYS:
+ * @SPI_KEYSET_ALL_KEYS: A special value for an AccessibleKeySet type, which tacitly
+ *                       includes all keycodes and keyvals for the specified modifier set.
+ **/
+#define SPI_KEYSET_ALL_KEYS NULL
+
+typedef unsigned long AccessibleKeyMaskType;
 
 /*
  *
@@ -142,7 +185,7 @@ SPI_exit (void);
  */
 
 /**
- * createEventListener:
+ * createAccessibleEventListener:
  * @callback : an #AccessibleEventListenerCB callback function, or NULL.
  *
  * Create a new #AccessibleEventListener with a specified callback function.
@@ -151,10 +194,10 @@ SPI_exit (void);
  *
  **/
 AccessibleEventListener *
-createEventListener (AccessibleEventListenerCB callback);
+createAccessibleEventListener (AccessibleEventListenerCB callback);
 
 /**
- * EventListener_addCallback:
+ * AccessibleEventListener_addCallback:
  * @listener: the #AccessibleEventListener instance to modify.
  * @callback: an #AccessibleEventListenerCB function pointer.
  *
@@ -164,11 +207,11 @@ createEventListener (AccessibleEventListenerCB callback);
  *
  **/
 boolean
-EventListener_addCallback (AccessibleEventListener *listener,
-                           AccessibleEventListenerCB callback);
+AccessibleEventListener_addCallback (AccessibleEventListener *listener,
+				     AccessibleEventListenerCB callback);
 
 /**
- * EventListener_removeCallback:
+ * AccessibleEventListener_removeCallback:
  * @listener: the #AccessibleEventListener instance to modify.
  * @callback: an #AccessibleEventListenerCB function pointer.
  *
@@ -178,20 +221,20 @@ EventListener_addCallback (AccessibleEventListener *listener,
  *
  **/
 boolean
-EventListener_removeCallback (AccessibleEventListener *listener,
-                              AccessibleEventListenerCB callback);
+AccessibleEventListener_removeCallback (AccessibleEventListener *listener,
+					AccessibleEventListenerCB callback);
 
 /**
- * createKeyListener:
- * @callback : an #KeystrokeListenerCB callback function, or NULL.
+ * createAccessibleKeystrokeListener:
+ * @callback : an #AccessibleKeystrokeListenerCB callback function, or NULL.
  *
- * Create a new #KeystrokeListener with a specified callback function.
+ * Create a new #AccessibleKeystrokeListener with a specified callback function.
  *
- * Returns: a pointer to a newly-created #KeystrokeListener.
+ * Returns: a pointer to a newly-created #AccessibleKeystrokeListener.
  *
  **/
-KeystrokeListener *
-createKeystrokeListener (KeystrokeListenerCB callback);
+AccessibleKeystrokeListener *
+createAccessibleKeystrokeListener (AccessibleKeystrokeListenerCB callback);
 
 /**
  * KeystrokeListener_addCallback:
@@ -204,22 +247,22 @@ createKeystrokeListener (KeystrokeListenerCB callback);
  *
  **/
 boolean
-KeystrokeListener_addCallback (KeystrokeListener *listener,
-			       KeystrokeListenerCB callback);
+AccessibleKeystrokeListener_addCallback (AccessibleKeystrokeListener *listener,
+					 AccessibleKeystrokeListenerCB callback);
 
 /**
- * KeystrokeListener_removeCallback:
- * @listener: the #KeystrokeListener instance to modify.
- * @callback: an #KeystrokeListenerCB function pointer.
+ * AccessibleKeystrokeListener_removeCallback:
+ * @listener: the #AccessibleKeystrokeListener instance to modify.
+ * @callback: an #AccessibleKeystrokeListenerCB function pointer.
  *
- * Remove an in-process callback function from an existing #KeystrokeListener.
+ * Remove an in-process callback function from an existing #AccessibleKeystrokeListener.
  *
  * Returns: #TRUE if successful, otherwise #FALSE.
  *
  **/
 boolean
-KeystrokeListener_removeCallback (KeystrokeListener *listener,
-				  KeystrokeListenerCB callback);
+AccessibleKeystrokeListener_removeCallback (AccessibleKeystrokeListener *listener,
+					    AccessibleKeystrokeListenerCB callback);
 
 /*
  *
@@ -251,6 +294,12 @@ KeystrokeListener_removeCallback (KeystrokeListener *listener,
 boolean
 registerGlobalEventListener (AccessibleEventListener *listener,
                              char *eventType);
+boolean
+deregisterGlobalEventListener (AccessibleEventListener *listener,
+                               char *eventType);
+boolean
+deregisterGlobalEventListenerAll (AccessibleEventListener *listener);
+
 
 /**
  * getDesktopCount:
@@ -277,7 +326,7 @@ getDesktopCount ();
  *
  **/
 Accessible*
-getDesktop (int n);
+getDesktop (int i);
 
 /**
  * getDesktopList:
@@ -297,35 +346,44 @@ int
 getDesktopList (Accessible **list);
 
 /**
- * registerKeystrokeListener:
- * @listener: a pointer to the #KeystrokeListener for which
+ * registerAccessibleKeystrokeListener:
+ * @listener: a pointer to the #AccessibleKeystrokeListener for which
  *            keystroke events are requested.
  *
- * Not Yet Implemented.
+ * [Partially Implemented.]
  *
  **/
 void
-registerKeystrokeListener (KeystrokeListener *listener, KeyMaskType keymask);
+registerAccessibleKeystrokeListener (AccessibleKeystrokeListener *listener,
+				     AccessibleKeySet *keys,
+				     AccessibleKeyMaskType modmask,
+				     AccessibleKeyEventMask eventmask,
+				     AccessibleKeyListenerSyncType sync_type);
+
+void
+deregisterAccessibleKeystrokeListener (AccessibleKeystrokeListener *listener,
+				       AccessibleKeyMaskType modmask);
 
 /**
  * generateKeyEvent:
- * @keycode: a #long indicating the keycode of the key event
+ * @keyval: a #long integer indicating the keycode or keysym of the key event
  *           being synthesized.
- * @meta: a #long indicating the key modifiers to be sent
- *        with the event, if any.
+ * @synth_type: a #AccessibleKeySynthType flag indicating whether @keyval
+ *           is to be interpreted as a keysym rather than a keycode
+ *           (SPI_KEYSYM) and whether to synthesize
+ *           SPI_KEY_PRESS, SPI_KEY_RELEASE, or both (SPI_KEY_PRESSRELEASE).
  *
  * Synthesize a keyboard event (as if a hardware keyboard event occurred in the
  * current UI context).
- * Not Yet Implemented.
  *
  **/
 void
-generateKeyEvent (long keyCode, long meta);
+generateKeyEvent (long int keyval, AccessibleKeySynthType synth_type);
 
 /**
  * generateMouseEvent:
- * @x: a #long indicating the screen x coordinate of the mouse event.
- * @y: a #long indicating the screen y coordinate of the mouse event.
+ * @x: a #long int indicating the screen x coordinate of the mouse event.
+ * @y: a #long int indicating the screen y coordinate of the mouse event.
  * @name: a string indicating which mouse event to be synthesized
  *        (e.g. "button1", "button2", "mousemove").
  *
@@ -334,7 +392,7 @@ generateKeyEvent (long keyCode, long meta);
  *
  **/
 void
-generateMouseEvent (long x, long y, char *name);
+generateMouseEvent (long int x, long int y, char *name);
 
 /*
  *
@@ -405,7 +463,6 @@ Accessible_getParent (Accessible *obj);
 
 /**
  * Accessible_getChildCount:
- *
  * @obj: a pointer to the #Accessible object on which to operate.
  *
  * Get the number of children contained by an #Accessible object.
@@ -431,7 +488,7 @@ Accessible_getChildCount (Accessible *obj);
  **/
 Accessible *
 Accessible_getChildAtIndex (Accessible *obj,
-                            long childIndex);
+                            long int childIndex);
 
 /**
  * Accessible_getIndexInParent:
@@ -450,9 +507,12 @@ Accessible_getIndexInParent (Accessible *obj);
 
 /**
  * Accessible_getRelationSet:
+ * @obj: a pointer to the #Accessible object on which to operate.
  *
  * Not Yet Implemented.
  *
+ * Returns: a pointer to an array of #AccessibleRelations.
+ *
  **/
 AccessibleRelation **
 Accessible_getRelationSet (Accessible *obj);
@@ -471,9 +531,12 @@ Accessible_getRole (Accessible *obj);
 
 /**
  * Accessible_getStateSet:
+ * @obj: a pointer to the #Accessible object on which to operate.
  *
  * Not Yet Implemented.
  *
+ * Returns: a pointer to an #AccessibleStateSet representing the object's current state.
+ *
  **/
 AccessibleStateSet *
 Accessible_getStateSet (Accessible *obj);
@@ -485,7 +548,6 @@ Accessible_getStateSet (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleAction.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleAction interface,
  *          #FALSE otherwise.
@@ -510,7 +572,6 @@ Accessible_isComponent (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleEditableText.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleEditableText interface,
  *          #FALSE otherwise.
@@ -523,7 +584,6 @@ Accessible_isEditableText (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleHypertext.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleHypertext interface,
  *          #FALSE otherwise.
@@ -536,7 +596,6 @@ Accessible_isHypertext (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleImage.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleImage interface,
  *          #FALSE otherwise.
@@ -549,7 +608,6 @@ Accessible_isImage (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleSelection.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleSelection interface,
  *          #FALSE otherwise.
@@ -562,7 +620,6 @@ Accessible_isSelection (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleTable.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleTable interface,
  *          #FALSE otherwise.
@@ -575,7 +632,6 @@ Accessible_isTable (Accessible *obj);
  * @obj: a pointer to the #Accessible instance to query.
  *
  * Query whether the specified #Accessible implements #AccessibleText.
- * Not Yet Implemented.
  *
  * Returns: #TRUE if @obj implements the #AccessibleText interface,
  *          #FALSE otherwise.
@@ -583,12 +639,6 @@ Accessible_isTable (Accessible *obj);
 boolean
 Accessible_isText (Accessible *obj);
 
-/**
- * Accessible_getAction:
- *
- * Not Yet Implemented.
- *
- **/
 AccessibleAction *
 Accessible_getAction (Accessible *obj);
 
@@ -679,8 +729,7 @@ Accessible_queryInterface (Accessible *obj, char *interface_name);
  */
 
 int
-AccessibleAction_ref (
-                      AccessibleAction *obj);
+AccessibleAction_ref (AccessibleAction *obj);
 
 int
 AccessibleAction_unref (AccessibleAction *obj);
@@ -689,28 +738,53 @@ long
 AccessibleAction_getNActions (AccessibleAction *obj);
 
 /**
- * AccessibleAction_getDescription:
- * @obj: a pointer to the #AccessibleAction to query.
+ * AccessibleAction_getName:
+ * @obj: a pointer to the #AccessibleAction implementor to query.
+ * @i: a long integer indicating which action to query.
  *
- * Get the description of 'i-th' action invokable on an
+ * Get the name of the '@i-th' action invokable on an
  *      object implementing #AccessibleAction.
  *
- * Not Yet Implemented.
+ * Returns: the 'event type' name of the action, as a UTF-8 string.
  *
- * Returns: a UTF-8 string describing the 'i-th' invokable action.
+ **/
+char *
+AccessibleAction_getName (AccessibleAction *obj, long int i);
+
+/**
+ * AccessibleAction_getDescription:
+ * @obj: a pointer to the #AccessibleAction to query.
+ * @i: a long integer indicating which action to query.
+ *
+ * Get the description of '@i-th' action invokable on an
+ *      object implementing #AccessibleAction.
+ *
+ * Returns: a UTF-8 string describing the '@i-th' invokable action.
  *
  **/
 char *
 AccessibleAction_getDescription (AccessibleAction *obj,
-                                 long index);
+                                 long int i);
 
 boolean
 AccessibleAction_doAction (AccessibleAction *obj,
-                           long index);
+                           long int i);
 
+/**
+ * AccessibleAction_getKeybinding:
+ * @obj: a pointer to the #AccessibleAction implementor to query.
+ * @i: a long integer indicating which action to query.
+ *
+ * Get the keybindings for the @i-th action invokable on an
+ *      object implementing #AccessibleAction, if any are defined.
+ *
+ * Returns: a UTF-8 string which can be parsed to determine the @i-th
+ * invokable action's keybindings.
+ *
+ **/
 char *
 AccessibleAction_getKeyBinding (AccessibleAction *obj,
-                                long index);
+                                long int i);
 
 /*
  *
@@ -785,6 +859,7 @@ AccessibleApplication_getID (AccessibleApplication *obj);
 
 /**
  * AccessibleApplication_pause:
+ * @obj: a pointer to the #Accessible object on which to operate.
  *
  * Attempt to pause the application (used when client event queue is
  *  over-full).
@@ -797,7 +872,8 @@ boolean
 AccessibleApplication_pause (AccessibleApplication *obj);
 
 /**
- * AccessibleApplication_pause:
+ * AccessibleApplication_resume:
+ * @obj: a pointer to the #Accessible object on which to operate.
  *
  * Attempt to resume the application (used after #AccessibleApplication_pause).
  * Not Yet Implemented.
@@ -822,14 +898,14 @@ AccessibleComponent_unref (AccessibleComponent *obj);
 
 boolean
 AccessibleComponent_contains (AccessibleComponent *obj,
-                              long x,
-                              long y,
+                              long int x,
+                              long int y,
                               AccessibleCoordType ctype);
 
 Accessible *
 AccessibleComponent_getAccessibleAtPoint (AccessibleComponent *obj,
-                                          long x,
-                                          long y,
+                                          long int x,
+                                          long int y,
                                           AccessibleCoordType ctype);
 
 /**
@@ -847,22 +923,22 @@ AccessibleComponent_getAccessibleAtPoint (AccessibleComponent *obj,
  **/
 void
 AccessibleComponent_getExtents (AccessibleComponent *obj,
-                                long *x,
-                                long *y,
-                                long *width,
-                                long *height,
+                                long int *x,
+                                long int *y,
+                                long int *width,
+                                long int *height,
                                 AccessibleCoordType ctype);
 
 void
 AccessibleComponent_getPosition (AccessibleComponent *obj,
-                                 long *x,
-                                 long *y,
+                                 long int *x,
+                                 long int *y,
                                  AccessibleCoordType ctype);
 
 void
 AccessibleComponent_getSize (AccessibleComponent *obj,
-                             long *width,
-                             long *height);
+                             long int *width,
+                             long int *height);
 
 void
 AccessibleComponent_grabFocus (AccessibleComponent *obj);
@@ -880,38 +956,39 @@ int
 AccessibleEditableText_unref (AccessibleEditableText *obj);
 
 boolean
-AccessibleEditableText_setRunAttributes (AccessibleEditableText *obj,
-					 const char *attributes,
-					 long startPos, long endPos);
+AccessibleEditableText_setAttributes (AccessibleEditableText *obj,
+				      const char *attributes,
+				      long int startOffset,
+				      long int endOffset);
 
-void
+boolean
 AccessibleEditableText_setTextContents (AccessibleEditableText *obj,
                                         const char *newContents);
 
-void
+boolean
 AccessibleEditableText_insertText (AccessibleEditableText *obj,
-                                   long position,
+                                   long int position,
                                    char *text,
-                                   long length);
+                                   long int length);
 
-void
+boolean
 AccessibleEditableText_copyText (AccessibleText *obj,
-                                 long startPos,
-                                 long endPos);
+                                 long int startPos,
+                                 long int endPos);
 
-void
+boolean
 AccessibleEditableText_cutText (AccessibleEditableText *obj,
-                                long startPos,
-                                long endPos);
+                                long int startPos,
+                                long int endPos);
 
-void
+boolean
 AccessibleEditableText_deleteText (AccessibleEditableText *obj,
-                                   long startPos,
-                                   long endPos);
+                                   long int startPos,
+                                   long int endPos);
 
-void
+boolean
 AccessibleEditableText_pasteText (AccessibleEditableText *obj,
-                                  long position);
+                                  long int position);
 
 /*
  *
@@ -919,27 +996,21 @@ AccessibleEditableText_pasteText (AccessibleEditableText *obj,
  *
  */
 
-int
-AccessibleHyperlink_ref (AccessibleHyperlink *obj);
-
-int
-AccessibleHyperlink_unref (AccessibleHyperlink *obj);
-
 long
 AccessibleHyperlink_getNAnchors (AccessibleHyperlink *obj);
 
 char *
 AccessibleHyperlink_getURI (AccessibleHyperlink *obj,
-                            long i);
+                            long int i);
 
-Accessible
+Accessible *
 AccessibleHyperlink_getObject (AccessibleHyperlink *obj,
-                               long i);
+                               long int i);
 
 void
 AccessibleHyperlink_getIndexRange (AccessibleHyperlink *obj,
-                                   long *startIndex,
-                                   long *endIndex);
+                                   long int *startIndex,
+                                   long int *endIndex);
 
 boolean
 AccessibleHyperlink_isValid (AccessibleHyperlink *obj);
@@ -960,12 +1031,12 @@ long
 AccessibleHypertext_getNLinks (AccessibleHypertext *obj);
 
 AccessibleHyperlink *
-AccessibleHyperText_getLink (AccessibleHypertext *obj,
-                             long linkIndex);
+AccessibleHypertext_getLink (AccessibleHypertext *obj,
+                             long int linkIndex);
 
 long
 AccessibleHypertext_getLinkIndex (AccessibleHypertext *obj,
-                                  long characterIndex);
+                                  long int characterOffset);
 
 /*
  *
@@ -984,13 +1055,13 @@ AccessibleImage_getImageDescription (AccessibleImage *obj);
 
 void
 AccessibleImage_getImageSize (AccessibleImage *obj,
-                              long *width,
-                              long *height);
+                              long int *width,
+                              long int *height);
 
 void
 AccessibleImage_getImagePosition (AccessibleImage *obj,
-                                  long *x,
-                                  long *y,
+                                  long int *x,
+                                  long int *y,
                                   AccessibleCoordType ctype);
 
 /*
@@ -1005,12 +1076,14 @@ AccessibleRelation_ref (AccessibleRelation *obj);
 int
 AccessibleRelation_unref (AccessibleRelation *obj);
 
-RELATION_TYPE
+AccessibleRelationType
 AccessibleRelation_getRelationType (AccessibleRelation *obj);
 
-Accessible *
-AccessibleRelation_getTarget (AccessibleRelation *obj);
+int
+AccessibleRelation_getNTargets (AccessibleRelation *obj);
 
+Accessible *
+AccessibleRelation_getTarget (AccessibleRelation *obj, int i);
 
 
 /*
@@ -1030,21 +1103,21 @@ AccessibleSelection_getNSelectedChildren (AccessibleSelection *obj);
 
 Accessible *
 AccessibleSelection_getSelectedChild (AccessibleSelection *obj,
-                                      long selectedChildIndex);
+                                      long int selectedChildIndex);
 
 boolean
 AccessibleSelection_selectChild (AccessibleSelection *obj,
-                                 long childIndex);
+                                 long int childIndex);
 
 boolean
 AccessibleSelection_deselectSelectedChild (AccessibleSelection *obj,
-                                           long selectedChildIndex);
+                                           long int selectedChildIndex);
 
 boolean
 AccessibleSelection_isChildSelected (AccessibleSelection *obj,
-                                     long childIndex);
+                                     long int childIndex);
 
-void
+boolean
 AccessibleSelection_selectAll (AccessibleSelection *obj);
 
 void
@@ -1065,15 +1138,15 @@ AccessibleStateSet_unref (AccessibleStateSet *obj);
 
 boolean
 AccessibleStateSet_contains (AccessibleStateSet *obj,
-                             ACCESSIBLE_STATE state);
+                             AccessibleState state);
 
 void
 AccessibleStateSet_add (AccessibleStateSet *obj,
-                        ACCESSIBLE_STATE state);
+                        AccessibleState state);
 
 void
 AccessibleStateSet_remove (AccessibleStateSet *obj,
-                           ACCESSIBLE_STATE state);
+                           AccessibleState state);
 
 boolean
 AccessibleStateSet_equals (AccessibleStateSet *obj,
@@ -1113,75 +1186,75 @@ long
 AccessibleTable_getNColumns (AccessibleTable *obj);
 
 Accessible *
-AccessibleTable_refAt (AccessibleTable *obj,
-                                 long row,
-                                 long column);
+AccessibleTable_getAccessibleAt (AccessibleTable *obj,
+                                 long int row,
+                                 long int column);
 
 long
 AccessibleTable_getIndexAt (AccessibleTable *obj,
-                            long row,
-                            long column);
+                            long int row,
+                            long int column);
 
 long
 AccessibleTable_getRowAtIndex (AccessibleTable *obj,
-                               long index);
+                               long int index);
 
 long
 AccessibleTable_getColumnAtIndex (AccessibleTable *obj,
-                                  long index);
+                                  long int index);
 
 char *
 AccessibleTable_getRowDescription (AccessibleTable *obj,
-				   long row);
+				   long int row);
 
 char *
 AccessibleTable_getColumnDescription (AccessibleTable *obj,
-				      long column);
+				      long int column);
 
 long
 AccessibleTable_getRowExtentAt (AccessibleTable *obj,
-                                long row,
-                                long column);
+                                long int row,
+                                long int column);
 
 long
 AccessibleTable_getColumnExtentAt (AccessibleTable *obj,
-                                   long row,
-                                   long column);
+                                   long int row,
+                                   long int column);
 
 Accessible *
 AccessibleTable_getRowHeader (AccessibleTable *obj,
-			      long row);
+			      long int row);
 
 Accessible *
 AccessibleTable_getColumnHeader (AccessibleTable *obj,
-				 long column);
+				 long int column);
 
 long
 AccessibleTable_getNSelectedRows (AccessibleTable *obj);
 
 long
 AccessibleTable_getSelectedRows (AccessibleTable *obj,
-                                 long **selectedRows);
+                                 long int **selectedRows);
 
 long
 AccessibleTable_getNSelectedColumns (AccessibleTable *obj);
 
 long
 AccessibleTable_getSelectedColumns (AccessibleTable *obj,
-                                    long **selectedColumns);
+                                    long int **selectedColumns);
 
 boolean
 AccessibleTable_isRowSelected (AccessibleTable *obj,
-                               long row);
+                               long int row);
 
 boolean
 AccessibleTable_isColumnSelected (AccessibleTable *obj,
-                                  long column);
+                                  long int column);
 
 boolean
 AccessibleTable_isSelected (AccessibleTable *obj,
-                            long row,
-                            long column);
+                            long int row,
+                            long int column);
 
 /*
  *
@@ -1200,79 +1273,87 @@ AccessibleText_getCharacterCount (AccessibleText *obj);
 
 char *
 AccessibleText_getText (AccessibleText *obj,
-                        long startOffset,
-                        long endOffset);
+                        long int startOffset,
+                        long int endOffset);
 
 long
 AccessibleText_getCaretOffset (AccessibleText *obj);
 
 char *
 AccessibleText_getAttributes (AccessibleText *obj,
-				 long offset,
-				 long *startOffset,
-				 long *endOfset);
+				 long int offset,
+				 long int *startOffset,
+				 long int *endOffset);
 
 
 boolean
 AccessibleText_setCaretOffset (AccessibleText *obj,
-                               long newOffset);
+                               long int newOffset);
 
 char *
 AccessibleText_getTextBeforeOffset (AccessibleText *obj,
-                                    long offset,
-                                    TEXT_BOUNDARY_TYPE type,
-				    long *startOffset, long *endOffset);
+                                    long int offset,
+                                    AccessibleTextBoundaryType type,
+				    long int *startOffset,
+				    long int *endOffset);
 
 char *
 AccessibleText_getTextAtOffset (AccessibleText *obj,
-                                    long offset,
-                                    TEXT_BOUNDARY_TYPE type,
-				long *startOffset, long *endOffset);
+				long int offset,
+				AccessibleTextBoundaryType type,
+				long int *startOffset,
+				long int *endOffset);
 
 char *
 AccessibleText_getTextAfterOffset (AccessibleText *obj,
-                                    long offset,
-                                    TEXT_BOUNDARY_TYPE type,
-				   long *startOffset, long *endOffset);
+				   long int offset,
+				   AccessibleTextBoundaryType type,
+				   long int *startOffset,
+				   long int *endOffset);
+
 unsigned long
 AccessibleText_getCharacterAtOffset (AccessibleText *obj,
-                                     long offset);
+                                     long int offset);
 
 void
 AccessibleText_getCharacterExtents (AccessibleText *obj,
-                                    long offset,
-                                    long *x,
-                                    long *y,
-                                    long *width,
-                                    long *height, AccessibleCoordType type);
+                                    long int offset,
+                                    long int *x,
+                                    long int *y,
+                                    long int *width,
+                                    long int *height,
+				    AccessibleCoordType type);
 
 long
 AccessibleText_getOffsetAtPoint (AccessibleText *obj,
-                                 long x,
-                                 long y, AccessibleCoordType type);
+                                 long int x,
+                                 long int y,
+				 AccessibleCoordType type);
 
 long
 AccessibleText_getNSelections (AccessibleText *obj);
 
 void
 AccessibleText_getSelection (AccessibleText *obj,
-			     long selectionNum, long *startOffset,
-			     long *endOffset);
+			     long int selectionNum,
+			     long int *startOffset,
+			     long int *endOffset);
 
 
 boolean
 AccessibleText_addSelection (AccessibleText *obj,
-			     long startOffset, long endOffset);
+			     long int startOffset,
+			     long int endOffset);
 
 boolean
 AccessibleText_removeSelection (AccessibleText *obj,
-				long selectionNum);
+				long int selectionNum);
 
 boolean
 AccessibleText_setSelection (AccessibleText *obj,
-			     long selectionNum,
-			     long startOffset,
-			     long endOffset);
+			     long int selectionNum,
+			     long int startOffset,
+			     long int endOffset);
 
 /*
  *
@@ -1280,20 +1361,28 @@ AccessibleText_setSelection (AccessibleText *obj,
  *
  */
 
-float
-AccessibleValue_getMinimumValue (AccessibleValue *value);
+int
+AccessibleValue_ref (AccessibleValue *obj);
+
+int
+AccessibleValue_unref (AccessibleValue *obj);
 
 float
-AccessibleValue_getCurrentValue (AccessibleValue *value);
+AccessibleValue_getMinimumValue (AccessibleValue *obj);
 
 float
-AccessibleValue_getMaximumValue (AccessibleValue *value);
+AccessibleValue_getCurrentValue (AccessibleValue *obj);
+
+float
+AccessibleValue_getMaximumValue (AccessibleValue *obj);
 
 boolean
-AccessibleValue_setCurrentValue (AccessibleValue *value,
+AccessibleValue_setCurrentValue (AccessibleValue *obj,
                                  float newValue);
 
 void
 spi_freeString (char *s);
 
+G_END_DECLS
+
 #endif
